#region MigraDoc - Creating Documents on the Fly
//
// Authors:
//   Stefan Lange
//   Klaus Potzesny
//   David Stephensen
//
// Copyright (c) 2001-2017 empira Software GmbH, Cologne Area (Germany)
//
// http://www.pdfsharp.com
// http://www.migradoc.com
// http://sourceforge.net/projects/pdfsharp
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
#endregion

namespace MigraDoc.DocumentObjectModel
{
    /// <summary>
    /// Represents 141 predefined colors.
    /// </summary>
    public static class Colors
    {
        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF0F8FF.
        /// </summary>
        public static readonly Color AliceBlue = new Color(0xFFF0F8FF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFAEBD7.
        /// </summary>
        public static readonly Color AntiqueWhite = new Color(0xFFFAEBD7);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF00FFFF.
        /// </summary>
        public static readonly Color Aqua = new Color(0xFF00FFFF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF7FFFD4.
        /// </summary>
        public static readonly Color Aquamarine = new Color(0xFF7FFFD4);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF0FFFF.
        /// </summary>
        public static readonly Color Azure = new Color(0xFFF0FFFF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF5F5DC.
        /// </summary>
        public static readonly Color Beige = new Color(0xFFF5F5DC);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFE4C4.
        /// </summary>
        public static readonly Color Bisque = new Color(0xFFFFE4C4);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF000000.
        /// </summary>
        public static readonly Color Black = new Color(0xFF000000);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFEBCD.
        /// </summary>
        public static readonly Color BlanchedAlmond = new Color(0xFFFFEBCD);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF0000FF.
        /// </summary>
        public static readonly Color Blue = new Color(0xFF0000FF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF8A2BE2.
        /// </summary>
        public static readonly Color BlueViolet = new Color(0xFF8A2BE2);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFA52A2A.
        /// </summary>
        public static readonly Color Brown = new Color(0xFFA52A2A);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFDEB887.
        /// </summary>
        public static readonly Color BurlyWood = new Color(0xFFDEB887);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF5F9EA0.
        /// </summary>
        public static readonly Color CadetBlue = new Color(0xFF5F9EA0);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF7FFF00.
        /// </summary>
        public static readonly Color Chartreuse = new Color(0xFF7FFF00);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFD2691E.
        /// </summary>
        public static readonly Color Chocolate = new Color(0xFFD2691E);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF7F50.
        /// </summary>
        public static readonly Color Coral = new Color(0xFFFF7F50);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF6495ED.
        /// </summary>
        public static readonly Color CornflowerBlue = new Color(0xFF6495ED);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFF8DC.
        /// </summary>
        public static readonly Color Cornsilk = new Color(0xFFFFF8DC);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFDC143C.
        /// </summary>
        public static readonly Color Crimson = new Color(0xFFDC143C);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF00FFFF.
        /// </summary>
        public static readonly Color Cyan = new Color(0xFF00FFFF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF00008B.
        /// </summary>
        public static readonly Color DarkBlue = new Color(0xFF00008B);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF008B8B.
        /// </summary>
        public static readonly Color DarkCyan = new Color(0xFF008B8B);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFB8860B.
        /// </summary>
        public static readonly Color DarkGoldenrod = new Color(0xFFB8860B);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFA9A9A9.
        /// </summary>
        public static readonly Color DarkGray = new Color(0xFFA9A9A9);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF006400.
        /// </summary>
        public static readonly Color DarkGreen = new Color(0xFF006400);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFBDB76B.
        /// </summary>
        public static readonly Color DarkKhaki = new Color(0xFFBDB76B);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF8B008B.
        /// </summary>
        public static readonly Color DarkMagenta = new Color(0xFF8B008B);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF556B2F.
        /// </summary>
        public static readonly Color DarkOliveGreen = new Color(0xFF556B2F);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF8C00.
        /// </summary>
        public static readonly Color DarkOrange = new Color(0xFFFF8C00);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF9932CC.
        /// </summary>
        public static readonly Color DarkOrchid = new Color(0xFF9932CC);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF8B0000.
        /// </summary>
        public static readonly Color DarkRed = new Color(0xFF8B0000);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFE9967A.
        /// </summary>
        public static readonly Color DarkSalmon = new Color(0xFFE9967A);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF8FBC8B.
        /// </summary>
        public static readonly Color DarkSeaGreen = new Color(0xFF8FBC8B);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF483D8B.
        /// </summary>
        public static readonly Color DarkSlateBlue = new Color(0xFF483D8B);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF2F4F4F.
        /// </summary>
        public static readonly Color DarkSlateGray = new Color(0xFF2F4F4F);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF00CED1.
        /// </summary>
        public static readonly Color DarkTurquoise = new Color(0xFF00CED1);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF9400D3.
        /// </summary>
        public static readonly Color DarkViolet = new Color(0xFF9400D3);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF1493.
        /// </summary>
        public static readonly Color DeepPink = new Color(0xFFFF1493);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF00BFFF.
        /// </summary>
        public static readonly Color DeepSkyBlue = new Color(0xFF00BFFF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF696969.
        /// </summary>
        public static readonly Color DimGray = new Color(0xFF696969);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF1E90FF.
        /// </summary>
        public static readonly Color DodgerBlue = new Color(0xFF1E90FF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFB22222.
        /// </summary>
        public static readonly Color Firebrick = new Color(0xFFB22222);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFFAF0.
        /// </summary>
        public static readonly Color FloralWhite = new Color(0xFFFFFAF0);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF228B22.
        /// </summary>
        public static readonly Color ForestGreen = new Color(0xFF228B22);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF00FF.
        /// </summary>
        public static readonly Color Fuchsia = new Color(0xFFFF00FF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFDCDCDC.
        /// </summary>
        public static readonly Color Gainsboro = new Color(0xFFDCDCDC);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF8F8FF.
        /// </summary>
        public static readonly Color GhostWhite = new Color(0xFFF8F8FF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFD700.
        /// </summary>
        public static readonly Color Gold = new Color(0xFFFFD700);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFDAA520.
        /// </summary>
        public static readonly Color Goldenrod = new Color(0xFFDAA520);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF808080.
        /// </summary>
        public static readonly Color Gray = new Color(0xFF808080);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF008000.
        /// </summary>
        public static readonly Color Green = new Color(0xFF008000);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFADFF2F.
        /// </summary>
        public static readonly Color GreenYellow = new Color(0xFFADFF2F);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF0FFF0.
        /// </summary>
        public static readonly Color Honeydew = new Color(0xFFF0FFF0);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF69B4.
        /// </summary>
        public static readonly Color HotPink = new Color(0xFFFF69B4);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFCD5C5C.
        /// </summary>
        public static readonly Color IndianRed = new Color(0xFFCD5C5C);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF4B0082.
        /// </summary>
        public static readonly Color Indigo = new Color(0xFF4B0082);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFFFF0.
        /// </summary>
        public static readonly Color Ivory = new Color(0xFFFFFFF0);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF0E68C.
        /// </summary>
        public static readonly Color Khaki = new Color(0xFFF0E68C);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFE6E6FA.
        /// </summary>
        public static readonly Color Lavender = new Color(0xFFE6E6FA);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFF0F5.
        /// </summary>
        public static readonly Color LavenderBlush = new Color(0xFFFFF0F5);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF7CFC00.
        /// </summary>
        public static readonly Color LawnGreen = new Color(0xFF7CFC00);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFFACD.
        /// </summary>
        public static readonly Color LemonChiffon = new Color(0xFFFFFACD);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFADD8E6.
        /// </summary>
        public static readonly Color LightBlue = new Color(0xFFADD8E6);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF08080.
        /// </summary>
        public static readonly Color LightCoral = new Color(0xFFF08080);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFE0FFFF.
        /// </summary>
        public static readonly Color LightCyan = new Color(0xFFE0FFFF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFAFAD2.
        /// </summary>
        public static readonly Color LightGoldenrodYellow = new Color(0xFFFAFAD2);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFD3D3D3.
        /// </summary>
        public static readonly Color LightGray = new Color(0xFFD3D3D3);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF90EE90.
        /// </summary>
        public static readonly Color LightGreen = new Color(0xFF90EE90);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFB6C1.
        /// </summary>
        public static readonly Color LightPink = new Color(0xFFFFB6C1);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFA07A.
        /// </summary>
        public static readonly Color LightSalmon = new Color(0xFFFFA07A);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF20B2AA.
        /// </summary>
        public static readonly Color LightSeaGreen = new Color(0xFF20B2AA);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF87CEFA.
        /// </summary>
        public static readonly Color LightSkyBlue = new Color(0xFF87CEFA);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF778899.
        /// </summary>
        public static readonly Color LightSlateGray = new Color(0xFF778899);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFB0C4DE.
        /// </summary>
        public static readonly Color LightSteelBlue = new Color(0xFFB0C4DE);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFFFE0.
        /// </summary>
        public static readonly Color LightYellow = new Color(0xFFFFFFE0);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF00FF00.
        /// </summary>
        public static readonly Color Lime = new Color(0xFF00FF00);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF32CD32.
        /// </summary>
        public static readonly Color LimeGreen = new Color(0xFF32CD32);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFAF0E6.
        /// </summary>
        public static readonly Color Linen = new Color(0xFFFAF0E6);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF00FF.
        /// </summary>
        public static readonly Color Magenta = new Color(0xFFFF00FF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF800000.
        /// </summary>
        public static readonly Color Maroon = new Color(0xFF800000);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF66CDAA.
        /// </summary>
        public static readonly Color MediumAquamarine = new Color(0xFF66CDAA);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF0000CD.
        /// </summary>
        public static readonly Color MediumBlue = new Color(0xFF0000CD);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFBA55D3.
        /// </summary>
        public static readonly Color MediumOrchid = new Color(0xFFBA55D3);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF9370DB.
        /// </summary>
        public static readonly Color MediumPurple = new Color(0xFF9370DB);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF3CB371.
        /// </summary>
        public static readonly Color MediumSeaGreen = new Color(0xFF3CB371);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF7B68EE.
        /// </summary>
        public static readonly Color MediumSlateBlue = new Color(0xFF7B68EE);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF00FA9A.
        /// </summary>
        public static readonly Color MediumSpringGreen = new Color(0xFF00FA9A);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF48D1CC.
        /// </summary>
        public static readonly Color MediumTurquoise = new Color(0xFF48D1CC);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFC71585.
        /// </summary>
        public static readonly Color MediumVioletRed = new Color(0xFFC71585);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF191970.
        /// </summary>
        public static readonly Color MidnightBlue = new Color(0xFF191970);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF5FFFA.
        /// </summary>
        public static readonly Color MintCream = new Color(0xFFF5FFFA);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFE4E1.
        /// </summary>
        public static readonly Color MistyRose = new Color(0xFFFFE4E1);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFE4B5.
        /// </summary>
        public static readonly Color Moccasin = new Color(0xFFFFE4B5);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFDEAD.
        /// </summary>
        public static readonly Color NavajoWhite = new Color(0xFFFFDEAD);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF000080.
        /// </summary>
        public static readonly Color Navy = new Color(0xFF000080);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFDF5E6.
        /// </summary>
        public static readonly Color OldLace = new Color(0xFFFDF5E6);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF808000.
        /// </summary>
        public static readonly Color Olive = new Color(0xFF808000);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF6B8E23.
        /// </summary>
        public static readonly Color OliveDrab = new Color(0xFF6B8E23);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFA500.
        /// </summary>
        public static readonly Color Orange = new Color(0xFFFFA500);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF4500.
        /// </summary>
        public static readonly Color OrangeRed = new Color(0xFFFF4500);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFDA70D6.
        /// </summary>
        public static readonly Color Orchid = new Color(0xFFDA70D6);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFEEE8AA.
        /// </summary>
        public static readonly Color PaleGoldenrod = new Color(0xFFEEE8AA);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF98FB98.
        /// </summary>
        public static readonly Color PaleGreen = new Color(0xFF98FB98);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFAFEEEE.
        /// </summary>
        public static readonly Color PaleTurquoise = new Color(0xFFAFEEEE);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFDB7093.
        /// </summary>
        public static readonly Color PaleVioletRed = new Color(0xFFDB7093);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFEFD5.
        /// </summary>
        public static readonly Color PapayaWhip = new Color(0xFFFFEFD5);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFDAB9.
        /// </summary>
        public static readonly Color PeachPuff = new Color(0xFFFFDAB9);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFCD853F.
        /// </summary>
        public static readonly Color Peru = new Color(0xFFCD853F);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFC0CB.
        /// </summary>
        public static readonly Color Pink = new Color(0xFFFFC0CB);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFDDA0DD.
        /// </summary>
        public static readonly Color Plum = new Color(0xFFDDA0DD);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFB0E0E6.
        /// </summary>
        public static readonly Color PowderBlue = new Color(0xFFB0E0E6);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF800080.
        /// </summary>
        public static readonly Color Purple = new Color(0xFF800080);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF0000.
        /// </summary>
        public static readonly Color Red = new Color(0xFFFF0000);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFBC8F8F.
        /// </summary>
        public static readonly Color RosyBrown = new Color(0xFFBC8F8F);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF4169E1.
        /// </summary>
        public static readonly Color RoyalBlue = new Color(0xFF4169E1);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF8B4513.
        /// </summary>
        public static readonly Color SaddleBrown = new Color(0xFF8B4513);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFA8072.
        /// </summary>
        public static readonly Color Salmon = new Color(0xFFFA8072);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF4A460.
        /// </summary>
        public static readonly Color SandyBrown = new Color(0xFFF4A460);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF2E8B57.
        /// </summary>
        public static readonly Color SeaGreen = new Color(0xFF2E8B57);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFF5EE.
        /// </summary>
        public static readonly Color SeaShell = new Color(0xFFFFF5EE);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFA0522D.
        /// </summary>
        public static readonly Color Sienna = new Color(0xFFA0522D);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFC0C0C0.
        /// </summary>
        public static readonly Color Silver = new Color(0xFFC0C0C0);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF87CEEB.
        /// </summary>
        public static readonly Color SkyBlue = new Color(0xFF87CEEB);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF6A5ACD.
        /// </summary>
        public static readonly Color SlateBlue = new Color(0xFF6A5ACD);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF708090.
        /// </summary>
        public static readonly Color SlateGray = new Color(0xFF708090);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFFAFA.
        /// </summary>
        public static readonly Color Snow = new Color(0xFFFFFAFA);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF00FF7F.
        /// </summary>
        public static readonly Color SpringGreen = new Color(0xFF00FF7F);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF4682B4.
        /// </summary>
        public static readonly Color SteelBlue = new Color(0xFF4682B4);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFD2B48C.
        /// </summary>
        public static readonly Color Tan = new Color(0xFFD2B48C);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF008080.
        /// </summary>
        public static readonly Color Teal = new Color(0xFF008080);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFD8BFD8.
        /// </summary>
        public static readonly Color Thistle = new Color(0xFFD8BFD8);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFF6347.
        /// </summary>
        public static readonly Color Tomato = new Color(0xFFFF6347);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #00FFFFFF.
        /// </summary>
        public static readonly Color Transparent = new Color(0x00FFFFFF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF40E0D0.
        /// </summary>
        public static readonly Color Turquoise = new Color(0xFF40E0D0);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFEE82EE.
        /// </summary>
        public static readonly Color Violet = new Color(0xFFEE82EE);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF5DEB3.
        /// </summary>
        public static readonly Color Wheat = new Color(0xFFF5DEB3);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFFFFF.
        /// </summary>
        public static readonly Color White = new Color(0xFFFFFFFF);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFF5F5F5.
        /// </summary>
        public static readonly Color WhiteSmoke = new Color(0xFFF5F5F5);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FFFFFF00.
        /// </summary>
        public static readonly Color Yellow = new Color(0xFFFFFF00);

        /// <summary>
        /// Gets the system-defined color that has the ARGB value of #FF9ACD32.
        /// </summary>
        public static readonly Color YellowGreen = new Color(0xFF9ACD32);
    }
}
